@@ -86,45 +86,45 @@ def regular_nucleotide_data_package() -> NucleotideSampleDataPackage:
     }
 
     mask_files = {
-        'SampleA': Path(data_dir, 'SampleA', 'snps.aligned.fa'),
-        'SampleB': Path(data_dir, 'SampleB', 'snps.aligned.fa'),
-        'SampleC': Path(data_dir, 'SampleC', 'snps.aligned.fa'),
+        'SampleA': Path(data_dir, 'SampleA', 'snps.aligned.minus-vcf.bed.gz'),
+        'SampleB': Path(data_dir, 'SampleB', 'snps.aligned.minus-vcf.bed.gz'),
+        'SampleC': Path(data_dir, 'SampleC', 'snps.aligned.minus-vcf.bed.gz'),
     }
 
     tmp_dir = Path(tempfile.mkdtemp())
-    return NucleotideSampleDataPackage.create_from_sequence_masks(sample_vcf_map=vcf_files,
-                                                                  masked_genomic_files_map=mask_files,
-                                                                  sample_files_processor=SerialSampleFilesProcessor(
-                                                                      tmp_dir))
+    return NucleotideSampleDataPackage.create_from_vcf_masks(sample_vcf_map=vcf_files,
+                                                             masked_genomic_files_map=mask_files,
+                                                             sample_files_processor=SerialSampleFilesProcessor(
+                                                                 tmp_dir))
 
 
 @pytest.fixture
 def snpeff_nucleotide_data_package() -> NucleotideSampleDataPackage:
     tmp_dir = Path(tempfile.mkdtemp())
-    return NucleotideSampleDataPackage.create_from_sequence_masks(sample_vcf_map=snpeff_sample_vcfs,
-                                                                  masked_genomic_files_map=None,
-                                                                  sample_files_processor=SerialSampleFilesProcessor(
-                                                                      tmp_dir))
+    return NucleotideSampleDataPackage.create_from_vcf_masks(sample_vcf_map=snpeff_sample_vcfs,
+                                                             masked_genomic_files_map=None,
+                                                             sample_files_processor=SerialSampleFilesProcessor(
+                                                                 tmp_dir))
 
 
 @pytest.fixture
 def snpeff_nucleotide_data_package_fake_duplicate_gene() -> NucleotideSampleDataPackage:
     tmp_dir = Path(tempfile.mkdtemp())
-    return NucleotideSampleDataPackage.create_from_sequence_masks(sample_vcf_map=snpeff_sample_vcfs_fake_dup,
-                                                                  masked_genomic_files_map=None,
-                                                                  sample_files_processor=SerialSampleFilesProcessor(
-                                                                      tmp_dir))
+    return NucleotideSampleDataPackage.create_from_vcf_masks(sample_vcf_map=snpeff_sample_vcfs_fake_dup,
+                                                             masked_genomic_files_map=None,
+                                                             sample_files_processor=SerialSampleFilesProcessor(
+                                                                 tmp_dir))
 
 
 @pytest.fixture
 def snpeff_nucleotide_data_package_parallel_variants() -> NucleotideSampleDataPackage:
     tmp_dir = Path(tempfile.mkdtemp())
     variants_processor_factory = MultipleProcessVcfVariantsTableProcessorFactory(ncores=2)
-    return NucleotideSampleDataPackage.create_from_sequence_masks(sample_vcf_map=snpeff_sample_vcfs,
-                                                                  masked_genomic_files_map=None,
-                                                                  sample_files_processor=SerialSampleFilesProcessor(
-                                                                      tmp_dir),
-                                                                  variants_processor_factory=variants_processor_factory)
+    return NucleotideSampleDataPackage.create_from_vcf_masks(sample_vcf_map=snpeff_sample_vcfs,
+                                                             masked_genomic_files_map=None,
+                                                             sample_files_processor=SerialSampleFilesProcessor(
+                                                                 tmp_dir),
+                                                             variants_processor_factory=variants_processor_factory)
 
 
 @pytest.fixture
@@ -141,7 +141,17 @@ def reference_service_with_snpeff_data(reference_service) -> ReferenceService:
 
 @pytest.fixture
 def sample_service(database):
-    return SampleService(database)
+    return SampleService(database, sql_select_limit=500)
+
+
+@pytest.fixture
+def sample_service_select1(database):
+    return SampleService(database, sql_select_limit=1)
+
+
+@pytest.fixture
+def sample_service_select2(database):
+    return SampleService(database, sql_select_limit=2)
 
 
 @pytest.fixture
